import 'dart:io';

import 'package:logging/logging.dart';
import 'package:path/path.dart' show dirname;
import 'package:path/path.dart' as path;

void initLog() {
  ///监听器能监听的范围
  Logger.root.level = Level.ALL;
  Logger.root.onRecord.listen((rec) {
    /// 基本的消息
    String log =
        '${rec.sequenceNumber}::${rec.level}::${rec.time}::${rec.message}';

    /// 添加错误信息
    if (rec.error != null) {
      log += '\n::${rec.error}';
    }

    /// 添加错误的堆栈
    if (rec.stackTrace != null) {
      log += '\n::${rec.stackTrace.toString()}';
    }

    /// 输出日志到控制台
    print(log);

    /// 只记录等级大于等于info的信息
    if (rec.level.value >= Level.INFO.value) {
      writeLog(log);
    }
  });
}

void writeLog(String log) async {
  var date = DateTime.now();
  var year = date.year;
  var month = date.month;
  var day = date.day;

  /// 如果recursive为true，会创建命名目录及父级目录
  var patch = dirname(path.fromUri(Platform.script.toString()));
  Directory directory =
      await new Directory('$patch/serverLog/$year').create(recursive: true);

  File file = new File('${directory.path}/$year-$month-$day.log');
  file.exists().then((isExists) {
    file.writeAsString(isExists ? '\n\n$log' : log, mode: FileMode.append);
  });
}
