// @dart = 2.8

import 'dart:async';
import 'dart:convert';
import 'dart:io';

import '../base/common.dart';
import '../globals.dart';
import '../runner/faircli_command.dart';
import '../util/util.dart';

class ServerCommand extends FaircliCommand {
  ServerCommand() {
    argParser.addOption(
      'description',
      defaultsTo: 'server',
      help: 'The description to start a local server for download fair patch.',
    );
    argParser.addOption(
      'directory',
      abbr: 'd',
      defaultsTo: '',
      help: 'fair project directory',
    );
  }

  @override
  final String name = 'server';

  @override
  final String description = 'Start a local server for download Fair patch';

  @override
  Future<FaircliCommandResult> runCommand() async {
    String currentPath = argResults['directory'];
    if (currentPath.isEmpty) {
      currentPath = localFileSystem.currentDirectory.path;
    }
    var fileRoot = userRootPath();
    var toolDir = fs.path.join(fileRoot, 'FairServer', 'bin');
    var toolPath = fs.path.join(toolDir, 'server.exe');

    try {
      cliPrint('Start local fair server...');
      var process = await Process.start(toolPath, ['-d', currentPath],
          workingDirectory: currentPath);
      process.stdout
          .transform<String>(utf8.decoder)
          .transform<String>(const LineSplitter())
          .listen((String line) => cliPrint('>>>>>> $line'));
      process.stderr.listen(stderr.add);
      await process.exitCode;
      Process.killPid(process.pid);
    } catch (e) {
      throwToolExit('Failed to start local server: $e');
    }
    return null;
  }
}
