import 'dart:convert';

import 'package:fair/fair.dart';
import 'package:fair_pushy/fair_pushy.dart';
import 'package:fair_pushy/src/files/fair_file.dart';
import 'package:fair_samples/plugins/net/fair_net_plugin.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'datasource/fair_test_data.dart';
import 'delegate/listview_common_delegate.dart';
import 'delegate/listview_delegate.dart';
import 'extension/ext.dart';
import 'fair_widget_page.dart';
import 'src/generated.fair.dart' as g;

Future<void> main() async {
  WidgetsFlutterBinding.ensureInitialized();
  FairPushy.init(debug: true);

  //Android应该是: storage/emulated/0/Android/data/com.demo_carrier/files/fairPushy/files/debug
  final devDir = await FairFile.getMainFolder();
  final devPath = '${devDir?.path}/files/debug';

  //这里的path是item的fair bundle产物
  FairDevTools.fairWidgetBuilder = (name, path) {
    ///纯item模版展示逻辑，一般item不会有decoration，所以套一个scaffold
    if ((name as String).contains('_item')) {
      return Scaffold(
        appBar: AppBar(
          title: Text(name),
        ),
        body: FairWidget(name: name, path: path, data: {
          'fairProps': jsonEncode(dataLogicMap.fuzzyMatching(name)),
        }),
      );
    } else if (templateWithNoItem.fuzzyMatching(name)) {
      ///只有父布局动态化没有动态化item的模版/写死数据的模版以及listview_template展示逻辑
      return FairWidget(
          name: name,
          path: path,
          delegate: ListViewDelegate(),
          data: {
            'fairProps': jsonEncode(dataLogicMap.fuzzyMatching(name)),
          });
    } else {
      ///其他动态化component模版展示逻辑
      return FairWidget(
          name: name,
          path: path,
          delegate: ListviewCommonDelegate(
              path: '$devPath/${name}_item.fair.json', //此处只兼容一种item的情况，后续可能需要扩展
              dataSource: itemDataLogicMap.fuzzyMatching(name)), //对应下标item数据源
          data: {
            'fairProps': jsonEncode(dataLogicMap.fuzzyMatching(name)),
            //外部列表动态化也可能会有数据源，但是目前demo模版没有，暂不处理
          });
    }
  };
  FairDevTools.config = FairDevConfig()
    ..addEnv(OnlineEnvInfo(
        envName: '环境1',
        updateUrl: 'https://fangfe.58.com/fairapp/module_patch_bundle',
        readOnly: true))
    ..addEnv(OnlineEnvInfo(envName: '环境2', updateUrl: '', readOnly: false));

  FairApp.runApplication(
    FairApp(
      delegate: {
        'lib_template_listview_template': (context, data) => ListViewDelegate(),
      },
      generated: g.AppGeneratedModule(),
      child: MyApp(),
    ),
    plugins: {'FairNet': FairNet()},
  );
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  // This widget is the root of your application.
  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Fair Samples',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(title: 'Flutter Demo Home Page'),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({Key? key, required this.title}) : super(key: key);

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.white,
      appBar: AppBar(
        // Here we take the value from the MyHomePage object that was created by
        // the App.build method, and use it to set our appbar title.
        title: Text('fair组件模板'),
      ),
      body: ListView(
        children: [
          addItem('gridview模板 + 网络请求插件', () {
            showWidget(
              fairPath: 'assets/fair/lib_template_gridview_template.fair.json',
              fairName: 'lib_template_gridview_template',
            );
          }),
          addItem('Fair开发者选项', () {
            FairDevTools.openDevPage(context);
          }),
        ],
      ),
    );
  }

  void showWidget({required fairPath, fairArguments, required fairName}) {
    Navigator.of(context).push(CupertinoPageRoute(builder: (_) {
      return FairWidgetPage(
        fairArguments: fairArguments,
        fairPath: fairPath,
        fairName: fairName,
      );
    }));
  }

  Widget addItem(String itemName, dynamic onPress) {
    return GestureDetector(
        onTap: onPress,
        child: Container(
            alignment: Alignment.centerLeft,
            height: 70,
            decoration: BoxDecoration(
                color: Colors.white,
                border: Border(
                    bottom: BorderSide(
                        color: Colors.grey.withOpacity(0.5), width: 0.5))),
            padding: const EdgeInsets.only(left: 20.0),
            child: Text(
              itemName,
              style: const TextStyle(
                fontSize: 20,
                fontWeight: FontWeight.bold,
              ),
              overflow: TextOverflow.ellipsis,
              maxLines: 1,
              textAlign: TextAlign.left,
            )));
  }
}
